xdoctest package
================

Subpackages
-----------

.. toctree::

    xdoctest.docstr
    xdoctest.utils

Submodules
----------

.. toctree::

   xdoctest.checker
   xdoctest.constants
   xdoctest.core
   xdoctest.directive
   xdoctest.doctest_example
   xdoctest.doctest_part
   xdoctest.dynamic_analysis
   xdoctest.exceptions
   xdoctest.parser
   xdoctest.plugin
   xdoctest.runner
   xdoctest.static_analysis


Module contents
---------------

.. automodule:: xdoctest
    :members:
    :undoc-members:
    :show-inheritance:
